@@ -6,7 +6,7 @@ use base qw(Text::Hatena::Node);
 sub init {
     my $self = shift;
     $self->{pattern} = qr/^>\|$/;
-    $self->{endpattern} = qr/^\|<$/;
+    $self->{endpattern} = qr/\|<$/;
     $self->{startstring} = qq|<pre>|;
     $self->{endstring} = qq|</pre>|;
 }
@@ -18,15 +18,17 @@ sub parse {
     $c->shiftline;
     my $t = "\t" x $self->{ilevel};
     $c->htmllines($t.$self->{startstring});
+    my $x = '';
     while ($c->hasnext) {
         my $l = $c->nextline;
         if ($l =~ /$self->{endpattern}/) {
+	    $x = $` || '';
             $c->shiftline;
             last;
         }
         $c->htmllines($c->shiftline);
     }
-    $c->htmllines($self->{endstring});
+    $c->htmllines($x . $self->{endstring});
 }
 
 1;
